﻿using System;
using System.Globalization;
using System.IO;
using System.Net;
using System.Net.Sockets;
using System.Text;

namespace CV5
{
    public static class Server
    {
        public static void ServerStart()
        {
            TcpListener listener = new TcpListener(IPAddress.Loopback, 4242);
            listener.Start();

            while (true)
            {
                using (TcpClient client = listener.AcceptTcpClient())
                using (NetworkStream stream = client.GetStream())
                using (StreamReader reader = new StreamReader(stream))
                using (StreamWriter writer = new StreamWriter(stream) { AutoFlush = true })
                {
                    string option = reader.ReadLine();

                    switch (option)
                    {
                        case "1":
                            writer.WriteMessage(DateTime.Now.ToString());
                            break;
                        case "2":
                            writer.WriteMessage(GetCurrencies());
                            break;
                        case "3":
                            writer.WriteMessage(GetIP());
                            break;
                        default:
                            writer.WriteMessage(Resources.GetString("invalidOption"));
                            break;
                    }
                }
            }
        }

        private static string GetCurrencies()
        {
            CultureInfo[] infos = CultureInfo.GetCultures(CultureTypes.SpecificCultures);
            StringBuilder sb = new StringBuilder();

            foreach (CultureInfo info in infos)
            {
                sb.Append(info.Name + " - ");
                RegionInfo region = new RegionInfo(info.Name);
                sb.AppendLine(region.CurrencyEnglishName + " / " + region.CurrencyNativeName + " (" + region.CurrencySymbol + ")");
            }

            return sb.ToString();
        }

        private static string GetIP()
        {
            WebClient wc = new WebClient();

            string[] contentLines;

            try
            {
                contentLines = wc.DownloadString("http://ping.eu/").Split('\r', '\n');
            }
            catch (WebException)
            {
                return "Download error";
            }

            int index = Array.FindIndex(contentLines, s => s.Contains("Your IP is"));

            if (index > -1)
            {
                string line = contentLines[index];
                int start = line.IndexOf("<b>") + 3;
                int end = line.IndexOf("</b>");

                return line.Substring(start, end - start);
            }

            return "Unknown";
        }
    }
}
